* ===================================================================
* Date: Mar 2024
* Paper: House Satisfaction and Social Comparison
*
* This programme prepares a dateset for loss aversion and moving adaptation analysis.
*
* Note
* 0. wavepanel_20210304_all combines annual indiviudal and household level datasets from the British Household Panel Survey, which is available at 
** University of Essex, Institute for Social and Economic Research. (2021). British Household Panel Survey: Waves 1-18, 1991-2009. [data collection]. 8th Edition. UK Data Service. SN: 5151, DOI: http://doi.org/10.5255/UKDA-SN-5151-2
* 1. house values and reference group house values are in log forms;
* 2. lead and lag after moving; 
* 3. homeowners only
* 4. Wave 11 is included to obtain move indicators
* 5. Within wave missing values re housat is moved to a later phase.
* 6. Add controls: child born that year; type of accomodation.
* 7. Use ssc install distinct/fsum if packages have not been loaded yet.
* 8. Move dummmy and duration of homeownership updcated on 26/04/2022.
* ===================================================================


*** Data prep

use wavepanel_20210304_all, clear
rename PID pid //cross-wave person identifier

xtset pid wave, delta(1)
order pid wave, first
tab wave, gen(wave)

* employment status
recode jobstatus (1 2=1 "Employed") (3 =2 "Unemployed") (4=3 "Retired") (5/10=4 "Inactive") (-9 -8 -1=.), gen(jobstatus_cat)
tab jobstatus_cat, gen(jbstat)

* num of kids
replace numkids=. if numkids<0
tab numkids

* move indicators
replace move=0 if move<0 //for panel continuity, coded as 0 'not moved' rather than missing.
tab move

* gen lrefval_med=log(refval_median)
gen lrefval_mean=log(refval_mean)
gen lrefval_med=log(refval_median)

* own/rent indicator
tab tenure 
gen mortgage = tenure - 1
// this sample includes only homeowners (outright or mortgage) - because home value is asked for homeowners only in the survey.
// 1 - owned outright; 2 - owned with mortgage

*-----------
* move indicator
*-----------

// moveyearc - closest moving year
// using wave-coded year, rather than reported moving year (moveyear), to avoid one-year difference.
gen moveyearc=year if move==1
by pid: replace moveyearc=moveyearc[_n-1] if moveyearc==. & moveyearc[_n-1]>0 & _n!=1

// total move count
bysort pid: egen movecount=sum(move)
tab movecount

//for frequent movers, which move this wave belongs to
bysort pid: gen movecount_rolling=sum(move==1)  

//indicator: move on the first wave
bysort pid: gen firstmove=1 if move[1]==1
replace firstmove=0 if mi(firstmove) 

* indicator: those who move more than once, consider only the first move
* movecount_rolling<2

//year before first move
bysort pid: egen year1stmv=min(moveyearc)
gen yrbefmv=year-year1stmv if movecount_rolling==0
tab yrbefmv
//year since closest move
gen yrsinmv=year-moveyearc if movecount_rolling==1
tab yrsinmv

//combine and make one var
gen yr_adapt=yrbefmv if !mi(yrbefmv)
replace yr_adapt=yrsinmv if !mi(yrsinmv)
set more off
tab yr_adapt

// missing housat values
// housat = . if wave ==11
// housat <0 if in other waves & not reported 
replace housat=.a if housat<0

// missing lfsat values
rename overallsat lfsat
replace lfsat=.a if lfsat<0

* sample size 

//number of individuals
distinct(pid) if !mi(housat) //individuals included in LA analysis
distinct(pid) if !mi(housat) & yr_adapt>=-5 & yr_adapt<=5  //individuals included in AD analysis (first move)
distinct(pid) if !mi(housat) & yr_adapt>=-5 & yr_adapt<=5 & firstmove!=1 //individuals included in AD analysis (first move excluding first wave) 

// income
gen income = anualincome/100000
gen income2 = income*income
gen lincome = log(anualincome)
label var income "Income/100000"

// type of accomodation
recode hstype (1 = 1 Detached) (2 = 2 Semi-detached) (3 4 = 3 Terraced) (5/8 = 4 Flat) (9/15 = 5 Others) (-9 = .) , gen(hstype_new) label(hstype)
label var hstype "Type of accomodation"
label var hstype_new "RECODE: Type of accomodation"
tab hstype_new, gen(hstype)

// type of job
recode socioeco (1 3 = 1 employer) (2 4 = 2 manager) (5 6 = 3 professional) (7/ 20 = 4 others) , gen(socioeco_new) label(hstype)
label var socioeco "Type of jobs"
label var socioeco_new "RECODE: Type of jobs"
tab socioeco_new, gen(socioeco)

// child born this year
bysort pid: gen flag = numkids[_n]-numkids[_n-1]
gen kid_born = (flag ==1 | flag == 2 | flag ==3)
gen finfine = max(finbetter, finsame)
drop flag
label var kid_born "Child born this year"

* Normalisation
gen nincome = (anualincome -  14938.07)/15220.86
gen nincome2 = nincome * nincome
gen nvalue = (value - 145588.55)/101811.86
gen nvalue2 = nvalue*nvalue

* scaling values
gen val0= value/100000
gen val02 = val0*val0
label var val0 "Value/100000" 

* Self-comparison variables

generate valloss = 0
generate vallossd = 0
replace valloss = d.nvalue if d.value < 0
replace vallossd = 1 if d.value < 0

generate incloss = 0
generate inclossd = 0
replace incloss = d.nincome if d.income < 0
replace inclossd = 1 if d.income < 0

generate lvalloss = 0
generate lvallossd = vallossd
replace lvalloss = d.lval if d.value < 0

generate lincloss = 0
generate linclossd = inclossd
replace lincloss = d.lincome if d.income < 0

//labelling
label var housat "Housing satisfaction" 
label var lfsat "Satisfaction with life overall" 
label var incsat "Satisfaction with income" 
label var spousat "Satisfaction with spouse" 
label var jobsat "Satisfaction with job" 
label var socsat "Satisfaction with social life" 
label var lei1sat "Satisfaction with amount of leisure time" 
label var lei2sat "Satisfaction with use of leisure time" 

label var value "Home value"
label var lval "Log home value"

label var age1 "Age: 16-24"
label var age2 "Age: 25-34"
label var age3 "Age: 35-44"
label var age4 "Age: 45-54"
label var age5 "Age: 55-64"
label var age6 "Age: >65"

label var edu1 "High education"
label var edu2 "Medium education"
label var edu3 "Low education"

label var numkids "Number of children"
label var jobstatus_cat "Job status"

label var talkneigh "Frequency of talking to neighbours"
label var finbetter "Change in financial position last year: better off"
label var finsame "Change in financial position last year: about same"
label var finfine "Change in financial position last year: better off or about same"
label var fin "Financial situation: not difficult"
label var space "Shortage of space"
label var neighnoi "Noise from neighbours"
label var streetnoi "Street noise"
label var damp "Damp walls/floors"
label var rot "Rot in windows/floors"
label var garden "Garden"
label var central "Central heating"
label var pollution "Pollution"
label var crime "Crime"
label var move "Move"
/*
label var movy1 "Moved - 1st non employment reason"
label var movy2 "Moved - 2nd non employment reason"
label var movjb "Moved for employment reasons"
label var movjba "Moved - employer relocated workplace "
label var movjbb "Moved - new job, same employer "
label var movjbc "Moved - new job, new employer"
label var movjbd "Moved - closer to same job"
label var movjbe "Moved - start own business "
label var movjbf "Moved - relocate own business "
label var movjbg "Moved - salary increase - new home "
label var movjbh "Moved - to seek work"
label var movjbi "Moved - other employment reason "

*/

label var type1 "Couple"
label var type2 "Lone parent"
label var type3 "Other household type"
label var type4 "Single"

label var lrefval_mean "Reference group mean"
label var lrefval_med "Reference group median"
label var selowd "Low (social economic status)"
label var sehighd "High (social economic status)"
label var edulowd "Low (education)"
label var eduhighd "High (education)"
label var agelowd "Low (age)"
label var agehighd "High (age)"
label var reglowd "Low (region)"
label var reghighd "High (region)"
label var reghighd "High (region)"

label define gender 1 "Male" 0 "Female"
label values gender gender


*--------------
*Descriptive Statistics
*--------------
// fsum - include labels
// xtsum - give witin- and between- sum stats

set more off
fsum housat value age1 age2 age3 age4 age5 gender edu1 edu2 edu3 numkids kid_born jbstat* type1 type2 type3 type4 ///
			 fin finbetter finsame talkneigh garden central space neighnoi streetnoi damp rot pollution crime hstype1 hstype2 hstype3 hstype4 hstype5 ///
			 if !mi(housat), u f(%12.2f)

set more off
fsum housat value age1 age2 age3 age4 age5 gender edu1 edu2 edu3 numkids jbstat* type1 type2 type3 type4 ///
			 fin finbetter finsame talkneigh garden central space neighnoi streetnoi damp rot pollution crime ///
			 if !mi(housat) & yr_adapt>=-5 & yr_adapt<=5 & firstmove!=1, u
			 
tab yr_adapt if !mi(housat) & yr_adapt>=-5 & yr_adapt<=5 & firstmove!=1


*------------------
* Move dummy (move)
* Duartion of home ownership (yearresid)
*------------------
capture drop move movecount
merge 1:1 pid wave using move.dta
drop _merge

replace yearresid=. if yearresid<0
tab yearresid

bysort pid: gen hhid_new = hhid[1]

sort pid wave

